#!/usr/bin/env python

#    This file is part of VASM.
#
#    VASM is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License v3 as published by
#    the Free Software Foundation.
#
#    VASM is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with VASM.  If not, see <http://www.gnu.org/licenses/>.

__author__ = "Moises Henriquez"
__author_email__ = "moc.liamg@xnl.E0M"[::-1]


import os
import unittest
import sys
import shutil
bepath = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
if not bepath in sys.path:
    sys.path.append(bepath)
import BOOTMODE


class BootModeTest(unittest.TestCase):
    def setUp(self):
        self.file = "/tmp/inittab"
        shutil.copy2("/etc/inittab", "/tmp/inittab")
        self.model = BOOTMODE.InitTab(self.file)
        self._original_data = []
        with open(self.file) as file:
            for line in file:
                self._original_data.append(line)
        
    
    def tearDown(self):
        # remove the temp file
        os.remove("/tmp/inittab")
    
    def test_methods(self):
        """ Test to make sure the class has the right methods """
        self.assertTrue(callable(self.model.getMode))
        self.assertTrue(callable(self.model.setMode))

    def test_getMode(self):
        mode = self.model.getMode()
        self.assertTrue(type(mode) == int)
    
    def test_setMode(self):
        # copy the file to tmp
        mode = 3
        self.model.setMode(mode)
        # make sure when we read it, it comes back the same as it went in
        result = self.model.getMode()
        self.assertEqual(mode, result)
        
        # Check that this method raises an exception if fed the wrong values
        self.assertRaises(AssertionError, self.model.setMode, 0)
        self.assertRaises(AssertionError, self.model.setMode, 6)

if __name__ == "__main__":
    unittest.main()
